@@ -35,9 +35,10 @@ GetNamesTaxa <- function(ProteinAccList , directorypath = NULL)
   #this link return information in tab formate (format = tab)
     ProteinName_url <- paste0("?query=accession:",ProteinAcc,"&format=tab&columns=",Colnames)
     RequestUrl <- paste0(baseUrl , ProteinName_url)
+    RequestUrl <- URLencode(RequestUrl)
     if (Request$status_code == 200){
       # parse the information in DataFrame
-      ProteinDataTable <- tryCatch(read.table(RequestUrl, header = TRUE, sep = '\t'), error=function(e) NULL)
+      ProteinDataTable <- tryCatch(read.csv(RequestUrl, header = TRUE, sep = '\t'), error=function(e) NULL)
       if (!is.null(ProteinDataTable))
       {
         ProteinInfoParsed <- as.data.frame(ProteinDataTable,row.names = ProteinAcc)
