@@ -38,7 +38,7 @@ GetSequences <- function(ProteinAccList, directorypath = NULL){
     RequestUrl <- URLencode(RequestUrl)
     if (Request$status_code == 200){
       # parse the information in DataFrame
-      ProteinDataTable <- tryCatch(read.table(RequestUrl, header = TRUE, sep = '\t'), error=function(e) NULL)
+      ProteinDataTable <- tryCatch(read.csv(RequestUrl, header = TRUE, sep = '\t'), error=function(e) NULL)
       if (!is.null(ProteinDataTable))
       {
         ProteinInfoParsed <- as.data.frame(ProteinDataTable,row.names = ProteinAcc)
